import {config} from '../../hook-ad-kit/config';
import {patchURL, loadContent} from '../../hook-ad-kit/loading'
import {animateIn,animateOut} from './Animation';
import {prependChild} from '../../hook-ad-kit/Util'
import {EventEmitter} from 'events';

let firstRun = false;
export default function () {
  let url = patchURL('./collapsed.html', config.richBaseURL);
  let adRoot = document.querySelector('#adRoot');
  let container = null;
  let content = null;
  let ee = new EventEmitter();
  let api = {};
  
  function catchAllHandler() {
    // internal cleanup here
    ee.emit('catchall');
  }
  
  function ctaHandler() {
    // internal cleanup here
    ee.emit('cta');
  }
  
  function expandHandler() {
    // internal cleanup here
    ee.emit('expand');
  }
  
  function bind() {
    Array.from(  container.querySelectorAll('.catch-all')).forEach(function (item) {
      item.addEventListener('click', catchAllHandler);
    });
    Array.from( container.querySelectorAll('.cta')).forEach(function (item) {
      item.addEventListener('click', ctaHandler);
    });
    Array.from(  container.querySelectorAll('.expand')).forEach(function (item) {
      item.addEventListener('click', expandHandler);
    });
  }
  
  function unbind() {
    Array.from(  container.querySelectorAll('.catch-all')).forEach(function (item) {
      item.removeEventListener('click', catchAllHandler);
    });
    Array.from(  container.querySelectorAll('.cta')).forEach(function (item) {
      item.removeEventListener('click', ctaHandler);
    });
    Array.from(  container.querySelectorAll('.expand')).forEach(function (item) {
      item.removeEventListener('click', expandHandler);
    });
  }
  
  function prepareContainer() {
    container = document.createElement("div");
    container.setAttribute('id', 'collapsedContainer');
    prependChild(adRoot, container)
  }
  
  api.preload = function () {
    return new Promise(function (resolve, reject) {
      console.log('PRELOAD');
      prepareContainer();
      loadContent(url, container, config.richBaseURL)
        .then(function () {
          content = container.querySelector('.content');
        })
        .then(resolve);
    });
  };
  api.init = function () {
    return new Promise(function (resolve, reject) {
      console.log('INIT');
      bind();
      if (firstRun === false) {
        firstRun = true;
        animateIn();
      } else {
        animateIn().progress(1, false);
      }
      resolve();
    })
  };
  api.ee = ee;
  api.exit = function () {
    return new Promise(function (resolve, reject) {
      unbind();
      animateOut();
      resolve();
    })
  };
  api.destroy = function () {
    return new Promise(function (resolve, reject) {
      ee.removeAllListeners();
      ee = null;
      adRoot.removeChild(container);
      resolve();
    })
  };
  return api;
}
