"use strict";
let fs = require('fs');
let path = require('path');
let glob = require('glob-promise');
let _ = require('lodash');
let imageSize = require('image-size');
let root = process.cwd();
let gutil = require('gulp-util');

function assetList(dir, filelist) {
  let files = fs.readdirSync(dir);
  filelist = filelist || [];
  files.forEach(function (file) {
    if (fs.statSync(path.join(dir, file)).isDirectory()) {
      filelist = assetList(path.join(dir, file), filelist);
    } else {
      filelist.push(path.join(dir, file));
    }
  });
  return filelist;
}

describe('Spritesheet PNGs', function () {
  it('should have dimensions that are a multiple of 4', function () {
    let pngDir = path.join(root, 'static', 'toSprite');
    let images = assetList(pngDir).filter(function (e) {
      return e.indexOf('.png') !== -1
    });
    let badImages = images.filter(function (e) {
      let dimensions = imageSize(e);
      if (dimensions.width % 4 !== 0 || dimensions.height % 4 !== 0) {
        let goodW = Math.ceil(dimensions.width / 4) * 4;
        let goodH = Math.ceil(dimensions.height / 4) * 4;
        console.log('!!    wrong dimensions:', e);
        console.log('!!    is: ' + dimensions.width + 'x' + dimensions.height);
        console.log('!!    should be: ' + goodW + 'x' + goodH);
        return true;
      }
    });
    expect(badImages.length).toEqual(0);
  });
});
describe('svg ID test', function () {
  let src = path.join(root, 'svgs', '/**/*.svg');
  let allClasses = [];
  it('no SVG IDs should be duplicates must be GLOBAL UNIQUE ', function () {
    let files = glob.sync(src);
    //console.log ("!!! files",files)
    files.forEach(function (file) {
      
      // inventory of all styles in each file
      let inventory = {};
      inventory.file = file;
      let content = fs.readFileSync(file, 'utf8');
      let matches = [];
      try {
        matches = content.match(/id\=\"(.*?)\"/g);
      } catch (err) {
      }
      let trimmed = [];
      try {
        
        //console.log ("!!! matches",matches)
        matches.forEach(function (match) {
          trimmed.push(match.replace('.', '').replace('{', ''))
        });
      } catch (err) {
       // console.error('no ID in this svg but that is ok', file, matches, err.message)
      }
      inventory.classMatches = trimmed;
      allClasses.push(inventory);
    });
    let classCollection = [];
    allClasses.forEach(function (inventory) {
      classCollection = _.concat(classCollection, inventory.classMatches);
    });
    let duplicates = _.filter(classCollection, function (value, index, iteratee) {
      return _.includes(iteratee, value, index + 1);
    });
    duplicates = duplicates.sort();
    console.log('!!dupes', duplicates.length);
    duplicates.forEach(function (dupe) {
      console.warn('!! SVG IDs DUPLICATE ERROR', dupe);
      allClasses.forEach(function (svg) {
        svg.classMatches.forEach(function (cssClass) {
          if (cssClass === dupe) {
            console.warn('\x1b[33m%s\x1b[0m', 'Appears In ' + path.relative(root, svg.file));
          }
        })
      })
    })
    expect(duplicates.length).toEqual(0);
  })
});
describe('svg css test', function () {
  let src = path.join(root, 'svgs', '/**/*.svg');
  let allClasses = [];
  it('no SVG CSS classes should be duplicates must be GLOBAL UNIQUE ', function () {
    let files = glob.sync(src);
    files.forEach(function (file) {
      
      // inventory of all styles in each file
      let inventory = {};
      inventory.file = file;
      let content = fs.readFileSync(file, 'utf8');
      let matches = [];
      try {
        let style = content.split('<style type="text/css">')[1].split('</style>')[0];
        matches = style.match(/\.(.*?){/g);
      } catch (err) {
      }
      let trimmed = [];
      matches.forEach(function (match) {
        trimmed.push(match.replace('.', '').replace('{', ''))
      });
      inventory.classMatches = trimmed;
      allClasses.push(inventory);
    });
    let classCollection = [];
    allClasses.forEach(function (inventory) {
      classCollection = _.concat(classCollection, inventory.classMatches);
    });
    let duplicates = _.filter(classCollection, function (value, index, iteratee) {
      return _.includes(iteratee, value, index + 1);
    });
    duplicates = duplicates.sort();
    duplicates.forEach(function (dupe) {
      console.warn('!! SVG CSS CLASS DUPLICATE ERROR', dupe);
      allClasses.forEach(function (svg) {
        svg.classMatches.forEach(function (cssClass) {
          if (cssClass === dupe) {
            console.warn('\x1b[31m%s\x1b[0m', 'Appears In ' + path.relative(root, svg.file));
          }
        })
      })
    })
    expect(duplicates.length).toEqual(0);
  })
});